available_animations: Displaying the Available Animations

Description Usage Value Examples

View source: R/available_animations.R

Description

The function displays a list of the available animations from the Animate.css library

Usage

1

Value

a list of the available animations by type of animation

Examples

1

feddelegrand7/GomoGomonoMi documentation built on Dec. 11, 2020, 9:50 a.m.