Learn R Programming

GomoGomonoMi (version 0.1.0)

use_gomo: Enable the Animate.css Library

Description

The function activates the capabilities of the animate.css library using its CDN. It should be run at the beginning of the document.

Usage

use_gomo()

Arguments

Value

called for the side effect of activating the animate.css library

Examples

Run this code
# NOT RUN {
# Put the function at the beginning of your Rmd document or Shiny app (UI)

use_gomo()



# }
# NOT RUN {

# }

Run the code above in your browser using DataLab