Learn R Programming

GomoGomonoMi (version 0.1.0)

available_animations: Displaying the Available Animations

Description

The function displays a list of the available animations from the Animate.css library

Usage

available_animations()

Arguments

Value

a list of the available animations by type of animation

Examples

Run this code
# NOT RUN {

available_animations()

# }
# NOT RUN {
# }

Run the code above in your browser using DataLab