powered by
The function displays a list of the available animations from the Animate.css library
available_animations()
a list of the available animations by type of animation
# NOT RUN { available_animations() # } # NOT RUN { # }
Run the code above in your browser using DataLab