powered by
The function activates the capabilities of the animate.css library using its CDN. It should be run at the beginning of the document.
use_gomo()
called for the side effect of activating the animate.css library
# NOT RUN { # Put the function at the beginning of your Rmd document or Shiny app (UI) use_gomo() # } # NOT RUN { # }
Run the code above in your browser using DataLab